@@ -29,8 +29,8 @@ def rename(
         metadata["xml:name"] = name
     if ns:
         metadata["xml:ns"] = ns
-    f.metadata = metadata
-    return f  # type: ignore
+    f.metadata = metadata  # type: ignore[assignment]
+    return f  # type: ignore[return-value]
 
 
 # NOTE: Actual return type is 'Field[_T]', but we want to help type checkers
@@ -43,12 +43,12 @@ def text(
         f = make_field(default=default)
     metadata = dict(f.metadata)
     metadata["xml:text"] = True
-    f.metadata = metadata
-    return f  # type: ignore
+    f.metadata = metadata  # type: ignore[assignment]
+    return f  # type: ignore[return-value]
 
 
 # NOTE: Actual return type is 'Field[_T]', but we want to help type checkers
 # to understand the magic that happens at runtime.
 # see https://github.com/python/typeshed/blob/master/stdlib/3.7/dataclasses.pyi
 def ignored() -> _T:
-    return field(init=False, compare=False)  # type: ignore
+    return field(init=False, compare=False)  # type: ignore[no-any-return]
