@@ -3,8 +3,8 @@ from __future__ import annotations
 from collections import defaultdict
 from typing import Any, Dict, List, Mapping, Optional, Type, TypeVar, Union
 
-from lxml.builder import ElementMaker  # type: ignore
-from lxml.etree import _Comment as Comment  # type: ignore
+from lxml.builder import ElementMaker  # type: ignore[import]
+from lxml.etree import _Comment as Comment  # type: ignore[import]
 
 from .lxml_utils import strip_ns
 from .options import Options
@@ -86,7 +86,7 @@ def _load_children(
         # try to find one matching type
         for base_type in child.base_types:
             try:
-                return load(base_type, value)
+                return load(base_type, value, options=options)
             except ValueError as e:
                 exceptions.append(e)
 
@@ -118,8 +118,8 @@ def _load_children(
             # nice path for default use-case
             base_type = child.base_types[0]
             if child.is_list:
-                return [load(base_type, v) for v in value]
-            return load(base_type, value)
+                return [load(base_type, v, options=options) for v in value]
+            return load(base_type, value, options=options)
 
         if child.is_list:
             return [_unpack_union_child(child, v) for v in value]
@@ -175,11 +175,11 @@ def load(
     else:
         text_values = {}
 
-    instance = cls(**attr_values, **text_values, **child_values)  # type: ignore
+    instance = cls(**attr_values, **text_values, **child_values)
     instance.__nsmap__ = el.nsmap
 
     try:
-        validate_fn = instance.xml_validate  # type: ignore
+        validate_fn = instance.xml_validate  # type: ignore[attr-defined]
     except AttributeError:
         pass
     else:
